"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usingFetch = exports.usingAjax = exports.loadScript = void 0;
const cache_1 = require("@zodash/cache");
const cache = cache_1.default.create();
/**
 * dynamic load script
 *
 * @param path script path
 */
function loadScript(path, options) {
    const { enableCache = true, ...attributes } = options !== null && options !== void 0 ? options : {};
    return new Promise((resolve, reject) => {
        if (enableCache && cache.get(path)) {
            return resolve();
        }
        const script = document.createElement('script');
        for (const key in attributes) {
            // script.setAttribute(key, attributes[key]);
            script[key] = attributes[key];
        }
        script.src = path;
        script.async = true;
        script.onerror = reject;
        script.onload = () => {
            // script.parentNode.removeChild(script);
            enableCache && cache.set(path, true);
            return resolve();
        };
        document.head.appendChild(script);
    });
}
exports.loadScript = loadScript;
/**
 * dynamic load script using ajax
 *
 * @param path script path
 */
function usingAjax(path, options) {
    var _a;
    const enableCache = (_a = options === null || options === void 0 ? void 0 : options.enableCache) !== null && _a !== void 0 ? _a : true;
    return new Promise((resolve, reject) => {
        if (enableCache && cache.get(path)) {
            return resolve();
        }
        const xhr = new XMLHttpRequest();
        xhr.onreadystatechange = function () {
            if (xhr.readyState === 4) {
                const script = document.createElement('script');
                script.innerText = xhr.responseText;
                script.onerror = reject;
                // script.onload = () => {
                //   // script.parentNode.removeChild(script);
                //   resolve();
                // };
                document.head.appendChild(script);
                setTimeout(() => {
                    enableCache && cache.set(path, true);
                    return resolve();
                }, 0);
            }
        };
        xhr.onerror = reject;
        xhr.open('GET', path);
        xhr.send();
    });
}
exports.usingAjax = usingAjax;
/**
 * dynamic load script using fetch
 *
 * @param path script path
 */
function usingFetch(path, options) {
    var _a;
    const enableCache = (_a = options === null || options === void 0 ? void 0 : options.enableCache) !== null && _a !== void 0 ? _a : true;
    return new Promise((resolve, reject) => {
        if (enableCache && cache.get(path)) {
            return resolve();
        }
        return fetch(path)
            .then((res) => res.text())
            .then((scriptText) => {
            const script = document.createElement('script');
            script.innerText = scriptText;
            script.onerror = reject;
            // script.onload = () => {
            //   // script.parentNode.removeChild(script);
            //   resolve();
            // };
            document.head.appendChild(script);
            setTimeout(() => {
                enableCache && cache.set(path, true);
                return resolve();
            }, 0);
        });
    });
}
exports.usingFetch = usingFetch;
